==> openwebmail-2.10.tgz: htdocs/openwebmail/javascript/htmlarea.openwebmail/popups/zh_TW.Big5/htmlarea-lang.js <==
// I18N constants

// Please translate the following part for your language
// 1. the left  side of fontname, font size and formatblock
// 2. the right side of tooltips

HTMLArea.I18N = {
	fontname: {
		"Arial":           'arial,helvetica,sans-serif',
		"Courier New":     'courier new,courier,monospace',
		"Georgia":         'georgia,times new roman,times,serif',
		"Tahoma":          'tahoma,arial,helvetica,sans-serif',
		"Times New Roman": 'times new roman,times,serif',
		"Verdana":         'verdana,arial,helvetica,sans-serif',
		"impact":          'impact',
		"WingDings":       'wingdings'
	},

	fontsize: {
		"1 (8 I)":  "1",
		"2 (10 I)": "2",
		"3 (12 I)": "3",
		"4 (14 I)": "4",
		"5 (18 I)": "5",
		"6 (24 I)": "6",
		"7 (36 I)": "7"
	},

	formatblock: {
		"D 1": "h1",
		"D 2": "h2",
		"D 3": "h3",
		"D 4": "h4",
		"D 5": "h5",
		"D 6": "h6",
		"q": "p",
		"}": "address",
		"w榡": "pre"
	},

	tooltips: {
		bold:           "",
		italic:         "",
		underline:      "u",
		strikethrough:  "Ru",
		subscript:      "UЦr",
		superscript:    "WЦr",
		justifyleft:    "a",
		justifycenter:  "m",
		justifyright:   "ak",
		justifyfull:    "k",
		orderedlist:    "s",
		unorderedlist:  "Ls",
		outdent:        "Y",
		indent:         "W[Y",
		forecolor:      "rC",
		backcolor:      "IC",
		horizontalrule: "ju",
		createlink:     "JWs",
		insertimage:    "JϤ",
		insertsound:    "Jn",
		inserttable:    "J",
		htmlmode:       " HTML Ҧ",
		popupeditor:    "js边",
		about:          "",
		help:           "DU",
		textindicator:  "ثer˦"
	}
};

==> openwebmail-2.51p2.tgz: htdocs/openwebmail/javascript/htmlarea.openwebmail/popups/zh_TW.Big5/htmlarea-lang.js <==
// I18N constants

// Please translate the following part for your language
// 1. the left  side of fontname, font size and formatblock
// 2. the right side of tooltips

HTMLArea.I18N = {
	fontname: {
		"Arial":           'arial,helvetica,sans-serif',
		"Courier New":     'courier new,courier,monospace',
		"Georgia":         'georgia,times new roman,times,serif',
		"Tahoma":          'tahoma,arial,helvetica,sans-serif',
		"Times New Roman": 'times new roman,times,serif',
		"Verdana":         'verdana,arial,helvetica,sans-serif',
		"impact":          'impact',
		"WingDings":       'wingdings'
	},

	fontsize: {
		"1 (8 I)":  "1",
		"2 (10 I)": "2",
		"3 (12 I)": "3",
		"4 (14 I)": "4",
		"5 (18 I)": "5",
		"6 (24 I)": "6",
		"7 (36 I)": "7"
	},

	formatblock: {
		"D 1": "h1",
		"D 2": "h2",
		"D 3": "h3",
		"D 4": "h4",
		"D 5": "h5",
		"D 6": "h6",
		"q": "p",
		"}": "address",
		"w榡": "pre"
	},

	tooltips: {
		bold:           "",
		italic:         "",
		underline:      "u",
		strikethrough:  "Ru",
		subscript:      "UЦr",
		superscript:    "WЦr",
		justifyleft:    "a",
		justifycenter:  "m",
		justifyright:   "ak",
		justifyfull:    "k",
		insertorderedlist:    "s",
		insertunorderedlist:  "Ls",
		outdent:        "Y",
		indent:         "W[Y",
		forecolor:      "rC",
		hilitecolor:    "IC",
		inserthorizontalrule: "ju",
		createlink:     "JWs",
		insertimage:    "JϤ",
		insertsound:    "Jn",
		inserttable:    "J",
		htmlmode:       " HTML Ҧ",
		popupeditor:    "js边",
		about:          "",
		showhelp:       "",
		textindicator:  "ثer˦",
		undo:           "_",
		redo:           "_",
		cut:            "ŤU",
		copy:           "ƻs",
		paste:          "KW"
	},

	buttons: {
		"ok":           "Tw",
		"cancel":       ""
	},

	msg: {
		"Path":         "|",
		"TEXT_MODE":    "z{bbݪO HTML H󪺭lX. ЫU [<>] s^ HTML sҦ."
	}
};
